;*******************************************************************************************
;   Beschreibung:    ber die externe OP-Schaltung wird die Spannung bzw. der Widerstand	 *
;							des Temperatursensors KTY81-210 gemessen, in die Temperatur				 *
;							umgerechnet und auf dem Display angezeigt.									 *
;																														 *
;*******************************************************************************************
;                                                                                          *
;    Dateiname:	 	Temperatur.asm						                                  		 *
;    Datum:        	03.11.2009                                                            *
;    Version: 			V1.0                                                                  *
;                                                                                          *
;    Autor:       	Michael Hofmann                                                       *
;    Internet:      	www.edmh.de                                                           *
;    e-mail:			info@edmh.de                                                          *
;                                                                                          *
;*******************************************************************************************
;    Bemerkungen:                                                                          *
;    		Das Beispiel kann mit dem Entwicklungsboard untersucht werden.			 				 *
;                                                                                          *
;*******************************************************************************************


	list      p=16f876a           ;definiert den verwendeten Prozessor
	#include <p16f876a.inc>       ;in diesem File stehen die Adressen und Bitnamen
	#include <Macros.inc>			;Makros fr die Bankumschaltung und die Zeitverzgerung
	#include <Display.inc>			;Makro fr die Initialisierung des Displays

	__CONFIG _CP_OFF & _WDT_OFF & _BODEN_OFF & _PWRTE_OFF & _XT_OSC & _WRT_OFF & _LVP_OFF & _DEBUG_ON & _CPD_OFF 
	; Mit '__CONFIG' werden die Configurationsbits gesetzt, z.B. Watchdog an/aus, Debugmodus

;===========================
;  DEFINITIONEN
;===========================
#define LED_1			PORTA, 2		;LED 1 liegt an Pin RA2
#define LED_2			PORTA, 3		;LED 2 liegt an Pin RA3
#define LED_3			PORTB, 4		;LED 3 liegt an Pin RB4
#define LED_4			PORTB, 5		;LED 4 liegt an Pin RB5

#define DISP_SI		PORTB, 0		;Serielle Daten zum Display
#define DISP_CLK		PORTB, 1		;Takt fr die Displaydaten
#define DISP_RS		PORTB, 2		;Unterscheidung zwischen Befehl und Daten
#define DISP_CSB		PORTB, 3		;Freigabe der Datenbertragung an das Display

;===========================
;  VARIABLEN
;===========================
w_temp        	EQU	0x70		;werden fr Interrupts verwendet, um den Status vor 
status_temp   	EQU	0x71		;der Interruptroutine zu sichern

DISP_SHIFT_REG	EQU	0x20		;Datum, welches an das Display gesendet werden soll
DISP_SHIFT_CNT	EQU	0x21		;Zhler fr die Datenausgabe

CALC_L_1			EQU	0x22		;1. Rechenregister fr Additionen und Subtraktionen
CALC_H_1			EQU	0x23		;High-Wort des CALC-Registers
CALC_L_2			EQU	0x24		;2. Rechenregister
CALC_H_2			EQU	0x25		;Bsp: CALC_x_1 + CALC_x_2 = CALC_x_1

COUNTER			EQU	0x26		;Zhler

ADC_L				EQU	0x30		;Kopie von AD-Wandlung
ADC_H				EQU	0x31	
ADC_Lx3			EQU	0x32		;AD-Wert mal 3
ADC_Hx3			EQU	0x33
Tx10_L			EQU	0x38		;Temperaturwert mal 10
Tx10_H			EQU	0x39
DISP_TAUSENDER	EQU	0x3A		;Tausenderstelle
DISP_HUNDERTER	EQU	0x3B		;Hunderterstelle
DISP_ZEHNER		EQU	0x3C		;Zehnerstelle
DISP_EINER		EQU	0x3D		;Einerstelle
VORZEICHEN		EQU	0x3E		;Vorzeichen (Es wird der Display-Code gespeichert)


;__________________________________________________________________________________________

		ORG     0x000				; Adresse, an die nach einem Reset gesprungen wird
		clrf    PCLATH          ; Rcksetzen der Page-Bits
  		goto    start           ; Springe zum Programmanfang

		ORG     0x004           ; Adresse, an die nach einem Interrupt gesprungen wird
		movwf	  w_temp          ; sichere den Inhalt des W-Registers
		movf    STATUS,w        ; verschiebe STATUS-Register ins W-Register
		movwf	  status_temp     ; sichere den Inhalt des STATUS-Registers

		; Ab hier kann der Code fr die Interruptroutinen stehen


		movf    status_temp,w     	; hole die Kopie des STATUS-Registers
		movwf	  STATUS            	; Sichere die Daten wieder zurck in das STATUS-Register
		swapf   w_temp,f
		swapf   w_temp,w          	; Sichere die Daten wieder zurck in das W-Register
		retfie                    	; Rcksprung vom Interrupt
;__________________________________________________________________________________________

start							; Beginn des Programms
	; Initialisierungen
	_BANK_0
	clrf PORTA				;Lsche alle Ausgangsports
	clrf PORTB
	clrf PORTC
	_BANK_1
	movlw b'10001110'		;AN0 = analoger Eingang, Ergebnis rechtsbndig
	movwf ADCON1
	movlw b'11110011'		;setze RA3 und RA2 als Ausgang und den Rest als Eingang
	movwf TRISA
	movlw b'11000000'		;setze RB7 und RB6 als Eingang und den Rest als Ausgang
	movwf TRISB
	movlw b'11111111'		;Alle Pins von Port C sind Eingnge
	movwf	TRISC
	_BANK_0
	movlw b'01000000'		;Initialisiere ADC, Kanal 0 (AN0), Fosz/8 (-> max 5 MHz Takt)
	movwf ADCON0

	bsf DISP_CSB			;Displaysignal CSB auf Highpegel setzen -> Display nicht aktiv
	bcf DISP_CLK			;Taktleitung auf Low setzen
	bcf DISP_SI				;Datenleitung auf Low setzen
	bcf DISP_RS				;Signalzustand von RS auf Kommando setzen

	_INIT_DISPLAY					;nach der Initialisierung ist der Inhalt des Displays
										;gelscht, bzw. mit Leerzeichen vollgeschrieben

main									;Beginn der Hauptschleife
	movlw 0x80						;Zeichen 1 in der 1. Zeile (=0x80 + 0x00)
	call SchreibeDispKommando	;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'T'						;Das Zeichen "T" soll in der 1. Zeile an Pos. 1 stehen
	call SchreibeDispDaten		;bertrage das Zeichen
	movlw A'='						;lade das Zeichen "=" in das W-Register
	call SchreibeDispDaten		;automatische Adresserhhung "=" = 1. Zeile 2. Stelle

lese_AN0								;Einlesen der Spannung an Pin AN0
	_BANK_1
	clrf ADRESL						;niederwertigen Teil des AD-Ergebnisses lschen
	_BANK_0
	clrf ADRESH						;hherwertigen Teil des AD-Ergebnisses lschen
	bsf ADCON0, ADON				;AD-Modul anschalten
	bsf ADCON0, GO_DONE			;AD-Wandlung starten
	btfsc ADCON0, GO_DONE
	goto $-1							;Warten, bis das bit GO_DONE von der Hardware zurckgesetzt
	nop								;wurde -> AD-Wandlung beendet
	
	call AD_konvertieren			;Umwandlung AD-Ergebnis in Spannungswert
	call Temp_berechnen			;Berechnung der Temperatur
	call B2D							;Umwandlung des binren Wertes in 3 Dezimalstellen

	movlw 0x82						;Pos. 3 der 1. Zeile
	call SchreibeDispKommando
	movf VORZEICHEN, W			;Ausgabe des Vorzeichens
	call SchreibeDispDaten
	movlw 0x30						;Umwandlung der Tausenderstelle in ASCII
	addwf DISP_TAUSENDER, W		;ASCII-Code = Zahlenwert + 0x30
	call SchreibeDispDaten
	movlw 0x30						;Umwandlung der Hunderterstelle in ASCII
	addwf DISP_HUNDERTER, W		;ASCII-Code = Zahlenwert + 0x30
	call SchreibeDispDaten
	movlw 0x30						;Umwandlung der Zehnerstelle in ASCII
	addwf DISP_ZEHNER, W
	call SchreibeDispDaten		;Ausgabe der ersten Stelle vor dem Komma
	movlw A'.'
	call SchreibeDispDaten		;Ausgabe des Dezimalpunktes
	movlw 0x30						;Umwandlung der Einerstelle in ASCII
	addwf DISP_EINER, W
	call SchreibeDispDaten		;Ausgabe der ersten Stelle hinter dem Komma

	movlw 0xDF						;Ausgabe der Temperatureinheit
	call SchreibeDispDaten
	movlw A'C'
	call SchreibeDispDaten

	_DELAY_TMR1_US d'500000'	;0,5 Sekunden warten, damit die Displayanzeige nicht flackert

	goto main						;Die Messung wird wieder neu gestartet

;__________________________________________________________________________________________

;===========================
;  Unterprogramme
;===========================

;*******************************************************************************************
; 16 bit Adition
; Die Werte fr die Addition mssen in den Registern CALC_x_x stehen
; Das Ergebnis steht dann im Register CALC_x_1
; CALC_x_1 + CALC_x_2 = CALC_x_1
;*******************************************************************************************
Add16
	movf CALC_L_2, W		;Hole das Lowbyte des 2. Summanden
	addwf CALC_L_1, F		;Addiere den 1. und 2. Summanden
	btfsc STATUS, C		;Prfe, ob ein berlauf aufgetreten ist
	incf CALC_H_1, F		;wenn ja, Highbyte um 1 erhhen
	movf CALC_H_2, W		;Hole das Highbyte des 2. Summanden
	addwf CALC_H_1, F    ;Addiere die Highbytes der Summanden

	return                  ; fertig

;*******************************************************************************************
; 16 Bit Subtraktion
; Wenn das Ergebnis ein negativer Wert ist, ist das Carryflag auf 0 gesetzt
; CALC_x_1 - CALC_x_2 = CALC_x_1
;*******************************************************************************************
Sub16
	movf CALC_L_2, W		;Hole das Lowbyte des Subtrahenden
	subwf CALC_L_1, F		;CALC_L_1 - CALC_L_2 = CALC_L_1
	btfss STATUS, C		;Ist ein bertrag aufgetreten
	incf CALC_H_2			;Ja, erhhe das Highbyte um 1
	movf CALC_H_2, W		;Hole das Highbyte des Subtrahenden
	subwf CALC_H_1, F		;CALC_H_1 - CALC_H_2 = CALC_H_2

	return

;*******************************************************************************************
; Wandlung einer Binrzahl (< 10000) aus der AD-Wandlung in eine Dezimalzahl
; Die Binrzahl steht in den Registern Tx10_H und Tx10_L
; die Dezimalstellen werden in den folgenden Registern gespeichert:
;		DISP_TAUSENDER = Tausenderstelle (dritte Stelle vor dem Komma)
;		DISP_HUNDERER  = Hunderterstelle (zweite Stelle vor dem Komma)
;		DISP_ZEHNER    = Zehnerstelle (erste Stelle vor dem Komma)
;		DISP_EINER     = Einerstelle (erste Stelle nach dem Komma)
;Bsp: 0x0141 = 321 -> Tausender = 0, Hunderter = 3, Zehner = 2, Einer = 1
;Um die Division durch 100 und 10 zu realisieren, wird der entsprechende Wert (z.B. 100)
;sooft von dem Spannunswert abgezogen, bis das Ergebnis negativ ist. Wenn das Ergebnis
;negativ ist, wurde zuviel abgezogen und der Wert muss wieder addiert werden. An dem
;Wert im Register COUNTER kann man nun ablesen welche dezimale Wertigkeit die Stelle hat.
;*******************************************************************************************
B2D
	_BANK_0
	movf Tx10_H, W			;Spannungswert fr Subtraktion kopieren 
	movwf CALC_H_1
	movf Tx10_L, W
	movwf CALC_L_1

	clrf COUNTER			;Zhler, der die Anzahl der Subtraktionen zhlt
subtrahieren_T
	movlw 0xE8				;Es sollen jeweils 1000 vom Wert abgezogen werden
	movwf CALC_L_2			;d'1000' = 0x3E8
	movlw 0x03
	movwf CALC_H_2
	call Sub16
	btfsc STATUS, C		;prfen, ob das Ergebnis positiv oder negativ ist
	goto ergebnis_Pos_T	;Ergebnis positiv -> es mssen nochmal 1000 abgezogen werden
	goto ergebnis_Neg_T	;Ergebnis negativ -> die Tausenderstelle ist nun bekannt
ergebnis_Pos_T
	incf COUNTER, F		;Zhler erhhen und nochmal 1000 abziehen
	goto subtrahieren_T
ergebnis_Neg_T
	movlw 0xE8				;es wurden 1000 zuviel abgezogen und mssen wieder addiert werden
	movwf CALC_L_2
	movlw 0x03
	movwf CALC_H_2
	call Add16				;es wird 1000 addiert
	movf COUNTER, W		;in Register COUNTER steht die Wertigkeit der Tausenderstelle
	movwf DISP_TAUSENDER	;Register COUNTER nach DISP_TAUSENDER kopieren

	clrf COUNTER			;Zhler, der die Anzahl der Subtraktionen zhlt
subtrahieren_H
	movlw d'100'			;Es sollen jeweils 100 von Wert abgezogen werden
	movwf CALC_L_2
	clrf CALC_H_2			;CALC_H_2 wird fr die Berechnung nicht bentigt -> Wert = 0
	call Sub16				;subtrahiere 100 von dem Spannungswert in den Registern Ux100_H/L
	btfsc STATUS, C		;prfen, ob das Ergebnis positiv oder negativ ist
	goto ergebnis_Pos_H	;Ergebnis positiv -> es mssen nochmal 100 abgezogen werden
	goto ergebnis_Neg_H	;Ergebnis negativ -> die Hunderterstelle ist nun bekannt
ergebnis_Pos_H
	incf COUNTER, F		;Zhler erhhen und nochmal 100 abziehen
	goto subtrahieren_H
ergebnis_Neg_H
	movlw d'100'			;es wurden 100 zuviel abgezogen und mssen wieder addiert werden
	movwf CALC_L_2
	clrf CALC_H_2
	call Add16				;es wird 100 addiert
	movf COUNTER, W		;in Register COUNTER steht die Wertigkeit der Hunderterstelle
	movwf DISP_HUNDERTER	;Register COUNTER nach DISP_HUNDERTER kopieren

	clrf COUNTER			;Wert in COUNTER fr die nchste Berechnung auf 0 zurcksetzen
subtrahieren_Z	
	movlw d'10'				;von dem Spannungswert werden jeweils 10 abgezogen
	movwf CALC_L_2
	clrf CALC_H_2			;CALC_H_2 wird fr die Berechnung nicht bentigt -> Wert = 0
	call Sub16				;subtrahiere 10 von dem verbleibenden Spannungswert
	btfsc STATUS, C		;prfen, ob das Ergebnis positiv oder negativ ist
	goto ergebnis_Pos_Z	;Ergebnis positiv -> es mssen nochmal 10 abgezogen werden
	goto ergebnis_Neg_Z	;Ergebnis negativ -> die Zehnerstelle ist nun bekannt
ergebnis_Pos_Z
	incf COUNTER, F		;Zhler erhhen und nochmal 10 abziehen
	goto subtrahieren_Z
ergebnis_Neg_Z
	movlw d'10'				;es wurden 10 zuviel abgezogen und mssen wieder addiert werden
	movwf CALC_L_2
	clrf CALC_H_2
	call Add16				;es wird 10 addiert
	movf COUNTER, W		;in Register COUNTER steht die Wertigkeit der Zehnerstelle
	movwf DISP_ZEHNER		;die Zehnerstelle von COUNTER nach DISP_ZEHNER kopieren
	
	movf CALC_L_1, W		;um die Einerstelle zu erhalten muss nur noch der Registerinhalt
	movwf DISP_EINER		;von CALC_L_1 nach DISP_EINER kopiert werden

	return

;*******************************************************************************************
;Daten von AD-Wandlung konvertieren
;Die Daten liegen nach der AD-Wandlung als 10 bit Wert in den Registern ADRESH und ADRESL
;Die Werte mssen right justified im AD-Register stehen
;Das Unterprogramm setzt eine Referenzspannung von 5V voraus und berechnet den
;10fachen Spannungswert des AD Ergebnisses. Dies ist ntig, da man nur mit ganzzahligen
;Werten rechnen kann. Das Ergebnis hat dann eine Nachkommastelle.
;Da der PIC keinen Multiplikationsbefehl zur verfgung stellt, muss dieser durch Additions-
;und Schiebebefehle realisiert werden. Die Formel fr die Berechnung der Temperatur lautet:
; T*10 = n LSB * 3      (1LSB=0,3C)
;Das Ergebnis von AD-Wert*3 steht in den Registern ADC_Lx3 und ADC_Hx3
;Am Ende des Unterprogramms steht der Temperaturwert*10 in den Registern
;Tx10_L und Tx10_H
;*******************************************************************************************
AD_konvertieren
	_BANK_0
	movf ADRESH, W			;AD-Wert in das W-Register kopieren
	;movlw 0x01				;Hiermit kann man die AD-Werte durch Testwerte berschreiben
	movwf ADC_H				;Highbyte des AD-Wertes in das Register ADC_H kopieren
	movwf ADC_Hx3			;Nochmals in das Register ADC_Hx25 kopieren
	_BANK_1
	movf ADRESL, W			;AD-Wert in das W-Register kopieren
	_BANK_0
	;movlw 0xE0				;Hiermit kann man die AD-Werte durch Testwerte berschreiben
	movwf ADC_L				;Lowbyte des AD-Wertes in das Register ADC_L kopieren
	movwf ADC_Lx3			;Nochmals in das Register ADC_Lx25 kopieren
	
	;Multiplikation mit 3, da 1LSB = 0,3C ist
	bcf STATUS, C			;Carryflag vor dem Verschieben lschen
	rlf ADC_Lx3, F 		;Multiplikation mit 2 durch Verschiebung nach links
	rlf ADC_Hx3, F
	
	movf ADC_L, W			;Den Wert nochmals addieren (Multiplikation mit 3)
	addwf ADC_Lx3, F
	btfsc STATUS, C
	incf ADC_Hx3, F
	movf ADC_H, W
	addwf ADC_Hx3, F

	movf ADC_Hx3, W		;AD-Wert in die Register fr die 10-fache Temperatur kopieren
	movwf Tx10_H
	movf ADC_Lx3, W
	movwf Tx10_L
	
	return

;*******************************************************************************************
;Berechnung der Temperatur
;Bei dem KTY81-210 betrgt die Temperatur ca. 0,3C/LSB
;Der konvertierte AD-Wert muss in den Register Tx10_L und Tx10_H stehen. Von diesem Wert
;wird Anzahl der LSB's bei 0C abgezogen, da die Temperatur positiv oder negativ sein kann.
;Die berechnete Temperatur steht anschlieend ohne Vorzeichen in den Registern Tx10_L und
;Tx10_H. Der ASCII-Code des Vorzeichens steht in dem Register VORZEICHEN und muss nur noch
;entsprechend ausgegeben werden.
;*******************************************************************************************
Temp_berechnen
	movf Tx10_L, W			;konvertierter AD-Wert steht in den Registern Tx10_L und Tx10_H
	movwf CALC_L_1
	movf Tx10_H, W
	movwf CALC_H_1
	movlw 0x6B				;375LSB = 0C (d'375'*3=1125=0x465)
	movwf CALC_L_2			;Korrektur:+6 -> 1125+6 = 0x46B
	movlw 0x4				;Die Korrektur ist abhngig von den Bauteiltoleranzen und sollte
	movwf CALC_H_2			;individuell ermittelt werden
	call Sub16				;subtrahiere 10 von dem verbleibenden Spannungswert
	btfsc STATUS, C		;prfen, ob das Ergebnis positiv oder negativ ist
	goto ergebnis_Pos_Temp	;Ergebnis positiv
	goto ergebnis_Neg_Temp	;Ergebnis negativ
ergebnis_Pos_Temp
	movf CALC_L_1, W
	movwf Tx10_L
	movf CALC_H_1, W
	movwf Tx10_H
	movlw A'+'				;ASCII-Code des Vorzeichens in das Register VORZEICHEN kopieren
	movwf VORZEICHEN
	return
ergebnis_Neg_Temp
	comf CALC_L_1			;um den neg. Zahlenwert zu erhalten, muss der Wert invertiert
	comf CALC_H_1			;werden und 1 addiert werden
	incf CALC_L_1			
	btfsc STATUS, C		;Bercksichtigung des berlaufs
	incf CALC_H_1

	movf CALC_L_1, W
	movwf Tx10_L
	movf CALC_H_1, W
	movwf Tx10_H
	
	movlw A'-'				;ASCII-Code des Vorzeichens in das Register VORZEICHEN kopieren
	movwf VORZEICHEN

	return

;*******************************************************************************************
; Es wird ein Kommando/Befehl an das Display gesendet.
; Das zu sendende Kommando muss im W-Register stehen, bevor das Unterprogramm
; aufgerufen wird.
; Es werden zwei Register bentigt:
; DISP_SHIFT_REG:	Befehl, der ausgegeben wird
; DISP_SHIFT_CNT: Anzahl der auszugebenden bits
;*******************************************************************************************
SchreibeDispKommando
	movwf DISP_SHIFT_REG		;Register mit den Daten, die ausgegeben werden sollen
	bcf DISP_CSB				;CSB auf Low setzen, damit das Display Daten empfangen kann 
	bcf DISP_RS					;RS auf Low setzen, da es sich um ein Kommando handelt
	bcf DISP_CLK				;Takt auf Low setzen, damit die Daten bei der steigenden
									;Flanke bernommen werden knnen
	movlw d'8'					;Zhler fr die Anzahl der zu bertragenden bits (=8)
	movwf DISP_SHIFT_CNT
shiftKommando
	rlf DISP_SHIFT_REG, F	;Bitverschiebung nach links. Das Carrybit wird am Pin SI
									;ausgegeben
	btfsc STATUS, C			;Wenn das Carryflag 0 ist, wird in der Pin SI mit dem Befehl
									;bcf DISP_SI auf Lowpegel gesetzt
	bsf DISP_SI					;Das Carryflag ist 1 -> setze Pin SI auf Highpegel
	btfss STATUS, C
	bcf DISP_SI
	nop							;eine kleine Wartezeit, um die bertragungsgeschwindigkeit
									;an das Display anzupassen
	bsf DISP_CLK				;mit der positiven Flanke bernimmt das Display die Daten
	nop
	bcf DISP_CLK				;negative Flanke des Taktes
	decfsz DISP_SHIFT_CNT, F	;Bitzhler um 1 verringern
	goto shiftKommando		;Wenn noch nicht 8 bits ausgegeben wurden, wird zum Label
									;shiftKommando gesprungen.
	bcf DISP_SI					;alle Daten bertragen -> Pin SI auf Low setzen
	bcf DISP_RS					;Pin RS auf Low setzen
	_DELAY_TMR1_US	d'30'		;geforderte Wartezeit des Displays

	return						;Rcksprung aus dem Unterprogramm

;*******************************************************************************************
; Es wird ein Datum an das Display gesendet.
; Das zu sendende Zeichen muss im W-Register stehen, bevor das Unterprogramm
; aufgerufen wird.
; Es werden zwei Register bentigt:
; DISP_SHIFT_REG:	Befehl, der ausgegeben wird
; DISP_SHIFT_CNT: Anzahl der auszugebenden bits
;*******************************************************************************************
SchreibeDispDaten
	movwf DISP_SHIFT_REG		;Das W-Register wird in das Reg. DISP_SHIFT_REG kopiert
	bcf DISP_CSB				;CSB auf Low setzen, damit das Display Daten empfangen kann 
	bsf DISP_RS					;RS auf High setzen, da es sich um ein Zeichen handelt
	bcf DISP_CLK				;Takt auf Low setzen, damit die Daten bei der steigenden
									;Flanke bernommen werden knnen
	movlw d'8'					;Es sollen 8 bits bertragen werden
	movwf DISP_SHIFT_CNT		;Zhler fr die bertragenen bits
shiftDaten
	rlf DISP_SHIFT_REG, F	;Das Zeichen wird nach links verschoben. Das Carryflag wird
									;an den Ausgang weitergegeben
	btfsc STATUS, C			;Prfen, welchen Wert das Carryflag hat
	bsf DISP_SI					;Carryflag = 1 -> Pin SI auf Highpegel setzen
	btfss STATUS, C			;Nochmal prfen, da immer nur ein Befehl bersprungen wird
	bcf DISP_SI					;Carryflag = 0 -> Pin SI auf Lowpegel setzen
	nop							;kurze Wartezeit, um die bertragungsgeschwindigkeit zu reduzieren
	bsf DISP_CLK				;mit dieser steigenden Flanke werden die Daten bernommen
	nop							;kurze Wartezeit
	bcf DISP_CLK				;negative Flanke des Taktes
	decfsz DISP_SHIFT_CNT, F	;ein bit wurde bertragen -> Zhler um 1 verringern
	goto shiftDaten			;nchstes bit bertragen
	bcf DISP_RS					;bertragung beendet Pin RS auf Low zurcksetzen
	bcf DISP_SI					;Pin SI auf Low zurcksetzen
	_DELAY_TMR1_US	d'30'		;geforderte Wartezeit (min. 26,3 us)

	return						;Rcksprung aus dem Unterprogramm

	END                		;Ende des Programms







